import QtQuick 2.0
import QtWebKit 3.0
import QtProcess 0.1

Item {
    id: appDetail

    property bool detailsShown: false
    property string appImage
    property string appName
    property string appPath
    property string appArgs
    property string appDescription

    anchors.fill: parent
    opacity: 0
    visible: opacity
    scale: 0.3

    function showDetails() {
        appDetail.detailsShown = true;
        showDetailsAnimation.restart();
        detailsShowTimer.restart();
        appDetailDescription
    }
    function hideDetails() {
        hideDetailsAnimation.restart();
    }
    function startApplicationProcess()
    {
        bounceAnimation.start()
        detailsShowTimer.restart()
        loadIndicator.active = 'true'
        loadIndicatorTimer.start()
        console.debug(appPath + "      " + appArgs)
        appProcess.startDetached()

    }

    Process
    {
        id: appProcess
            program: appPath
            arguments: smallResolution ? appArgs+" -smallResolution" : appArgs
    }

    ParallelAnimation {
        id: showDetailsAnimation
        NumberAnimation { target: appDetail; property: "opacity"; to: 1.0; duration: 500; easing.type: Easing.InOutQuad }
        NumberAnimation { target: appDetail; property: "scale"; to: 1.0; duration: 500; easing.type: Easing.InOutQuad }
    }
    SequentialAnimation {
        id: hideDetailsAnimation
        ParallelAnimation {
            NumberAnimation { target: appDetail; property: "opacity"; to: 0; duration: 500; easing.type: Easing.InOutQuad }
            NumberAnimation { target: appDetail; property: "scale"; to: 0.3; duration: 500; easing.type: Easing.InOutQuad }
        }
        PropertyAction { target: appDetail; property: "detailsShown"; value: false }
    }

    Rectangle {
        id: backgroundItem
        anchors.centerIn: parent
        anchors.verticalCenterOffset: 50
        width: parent.width - 50
        height: parent.height - 130
        opacity: 0.9
        radius: 5
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#0f0f0f" }
            GradientStop { position: 0.3; color: "#404040" }
            GradientStop { position: 1.0; color: "#090909" }
        }
    }

    Item {
        id: leftSide
        anchors.fill: backgroundItem
        anchors.margins: 1

        Column {
            id: appDetailColumn
            y: 20
            anchors.left: parent.left
            width: verticalSeparator.x - backgroundItem.x
            height: parent.height - 170
            spacing: 8

            Image {
                id: appIconImage
                y: 20
                width: 150
                height: 150
                anchors.horizontalCenter: parent.horizontalCenter
                source: appImage
                fillMode: Image.PreserveAspectFit
                smooth: true
            }

            Text {
                id: appNameText
                width: parent.width - 10
                //x: 10
                wrapMode: Text.WordWrap
                color: "#ffffff"
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: text.length < 12 ? mainLauncherWindow.fontL  : mainLauncherWindow.fontMM
                text: appName
            }
        }
    }

    Item {
        id: rightSide
        anchors.fill: backgroundItem
        anchors.margins: 1

        WebView {
            id: appDetailDescription
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            height: parent.height - 20
            width: backgroundItem.width - (verticalSeparator.x - backgroundItem.x) - 20

            url: appDescription.match("Test Description")  ?  "../../applications/timesys/html/dummy.html" : appDescription //TODO change the url to the description file

            MouseArea{
                anchors.fill: parent
                onPressed: {
                    mouse.accepted = false
                    detailsShowTimer.restart()
                }
            }

        }
    }

    Rectangle {
        id: verticalSeparator
        anchors.horizontalCenter: backgroundItem.horizontalCenter
        anchors.horizontalCenterOffset: -230
        anchors.bottom: backgroundItem.bottom
        anchors.bottomMargin: 10
        width: 1
        height: backgroundItem.height - 20
        color: "#707070"
    }

    //Button - start the application
    Image {
        id: startAppImage
        anchors.bottom: backgroundItem.bottom
        anchors.bottomMargin: 40
        anchors.left: backgroundItem.left
        anchors.leftMargin: (verticalSeparator.x - backgroundItem.x)/2 - 100

        source: "../../resources/mediumResolution/app-launch.png"
        fillMode: Image.PreserveAspectFit
        smooth: true

        MouseArea {
            anchors.fill: parent
            onClicked:
                startApplicationProcess()
        }

        transform: Scale {
            id: scaleTransform
            property real scale: 1
            xScale: scale
            yScale: scale
        }

        SequentialAnimation {
            id: bounceAnimation
            loops: 1
            PropertyAnimation {
                target: scaleTransform
                properties: "scale"
                from: 1.0
                to: 1.3
                duration: 200
            }
            PropertyAnimation {
                target: scaleTransform
                properties: "scale"
                from: 1.3
                to: 1.0
                duration: 200
            }
        }
    }

    LoadIndicator { id: loadIndicator; anchors.centerIn: backgroundItem }

    Timer {
        id: loadIndicatorTimer
        interval: 4000;
        repeat: false
        onTriggered: loadIndicator.active = false
    }

    Timer {
        id: detailsShowTimer
        interval: 15000;
        repeat: false
        onTriggered: hideDetails()
    }
}

