import QtQuick 2.0


Item {
    id: helpScr
    anchors.fill:parent
    property bool direction: false

    function showHelp() {
        showHelpAnimation.restart();
        helpShowTimer.restart();
    }
    function hideHelp() {
        hideHelpAnimation.restart();
    }

    Rectangle {
        id: helpRect
        anchors.fill: parent
        opacity: 0.85
        radius: 5
        z: 1000
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#0f0f0f" }
            GradientStop { position: 0.3; color: "#404040" }
            GradientStop { position: 1.0; color: "#090909" }
        }
        MouseArea
        {
            anchors.fill: parent
            onClicked: { hideHelp() }
        }

        Image
        {
            id: handLeft
            anchors.left: parent.left
            anchors.leftMargin: 180
            anchors.bottom: textLaunch.top
            anchors.bottomMargin: 10
            source: "../../resources/mediumResolution/hand-left.png"
            transform: Rotation {
                origin.x: handLeft.width / 2
                origin.y: handLeft.height / 2
                axis.x: 0
                axis.y: 1
                axis.z: 0
                angle: 180
            }
        }

        Image
        {
            id: arrowLeft
            anchors.top: parent.top
            anchors.topMargin: 30
            x: 70
            source: "../../resources/mediumResolution/arrow-left.png"

            SequentialAnimation{
                running: true
                loops: Animation.Infinite
                NumberAnimation { target: arrowLeft; property: "x"; to: 100; duration: 500; easing.type: Easing.InOutQuad }
                NumberAnimation { target: arrowLeft; property: "x"; to: 50; duration: 500; easing.type: Easing.InOutQuad }
            }
        }
        Image
        {
            id: arrowRight
            x: parent.width - 170
            anchors.top: parent.top
            anchors.topMargin: 30
            source: "../../resources/mediumResolution/arrow-right.png"

            SequentialAnimation{
                running: true
                loops: Animation.Infinite
                NumberAnimation { target: arrowRight; property: "x"; to: parent.width-200; duration: 500; easing.type: Easing.InOutQuad }
                NumberAnimation { target: arrowRight; property: "x"; to: parent.width-150; duration: 500; easing.type: Easing.InOutQuad }
            }
        }


        Text
        {
            id: textScroll
            anchors.top: parent.top
            anchors.topMargin: 30
            anchors.horizontalCenter: parent.horizontalCenter
            color: "white"
            font.pointSize: 17
            text: "Swipe area - scroll left/right"
        }
        Text
        {
            id: textDetail
            anchors.centerIn: parent
            color: "white"
            font.pointSize: 17
            text: "Application Detail area"
        }
        Text
        {
            id: textLaunch
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 260
            font.pointSize: 17
            color: "white"
            text: "Start selected application"
        }

        Image
        {
            id: timesysLogo
            anchors.right: parent.right
            anchors.rightMargin: 20
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 60
            source: "../../resources/mediumResolution/logo-timesys.png"
        }
        Text
        {
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 30
            anchors.right: parent.right
            anchors.rightMargin: 30
            color: "white"
            width: 150
            font.pointSize: 12
            wrapMode: Text.WordWrap
            text: "Version: 0.3"
        }

    }

    ParallelAnimation {
        id: showHelpAnimation
        NumberAnimation { target: helpScr; property: "opacity"; to: 1.0; duration: 500; easing.type: Easing.InOutQuad }
        NumberAnimation { target: helpScr; property: "scale"; to: 1.0; duration: 500; easing.type: Easing.InOutQuad }
    }
    ParallelAnimation {
        id: hideHelpAnimation
        NumberAnimation { target: helpScr; property: "opacity"; to: 0; duration: 500; easing.type: Easing.InOutQuad }
        NumberAnimation { target: helpScr; property: "scale"; to: 0.3; duration: 500; easing.type: Easing.InOutQuad }
    }

    Timer {
        id: helpShowTimer
        interval: 8000;
        repeat: false
        running: true
        onTriggered: hideHelp()
    }
/*
    Timer {
        id: bounceTimer
        interval: 1000;
        repeat: true
        running: true
        onTriggered: {
            if(direction)
            {
                arrowLeft.x = arrowLeft.x+50
                arrowRight.x = arrowRight.x-50
            }else{
                arrowLeft.x = arrowLeft.x-50
                arrowRight.x = arrowRight.x+50
            }
            direction = !direction
        }
    }
    */
}
